# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/MemoryStateCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.devices.generic.MemoryState_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/MemoryStateCollection.proto',
  package='rst.devices.generic',
  serialized_pb='\n/rst/devices/generic/MemoryStateCollection.proto\x12\x13rst.devices.generic\x1a%rst/devices/generic/MemoryState.proto\"J\n\x15MemoryStateCollection\x12\x31\n\x07\x65lement\x18\x01 \x03(\x0b\x32 .rst.devices.generic.MemoryStateB\x1b\x42\x19MemoryStateCollectionType')




_MEMORYSTATECOLLECTION = _descriptor.Descriptor(
  name='MemoryStateCollection',
  full_name='rst.devices.generic.MemoryStateCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.devices.generic.MemoryStateCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=111,
  serialized_end=185,
)

_MEMORYSTATECOLLECTION.fields_by_name['element'].message_type = rst.devices.generic.MemoryState_pb2._MEMORYSTATE
DESCRIPTOR.message_types_by_name['MemoryStateCollection'] = _MEMORYSTATECOLLECTION

class MemoryStateCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MEMORYSTATECOLLECTION

  # @@protoc_insertion_point(class_scope:rst.devices.generic.MemoryStateCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\031MemoryStateCollectionType')
# @@protoc_insertion_point(module_scope)
