# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/Todo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.calendar.DateTime_pb2
import rst.calendar.Entry_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/Todo.proto',
  package='rst.calendar',
  serialized_pb='\n\x17rst/calendar/Todo.proto\x12\x0crst.calendar\x1a\x1brst/calendar/DateTime.proto\x1a\x18rst/calendar/Entry.proto\"\xb3\x02\n\x04Todo\x12\"\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x13.rst.calendar.Entry\x12-\n\rcompleted_utc\x18\x02 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x12\n\x07percent\x18\x03 \x01(\r:\x01\x30\x12@\n\x0btodo_status\x18\x04 \x01(\x0e\x32\x1d.rst.calendar.Todo.TodoStatus:\x0cNEEDS_ACTION\x12#\n\x03\x64ue\x18\x05 \x01(\x0b\x32\x16.rst.calendar.DateTime\x12\x10\n\x08\x64uration\x18\x06 \x01(\x12\"K\n\nTodoStatus\x12\x10\n\x0cNEEDS_ACTION\x10\x01\x12\r\n\tCOMPLETED\x10\x02\x12\x0e\n\nIN_PROCESS\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x42\nB\x08TodoType')



_TODO_TODOSTATUS = _descriptor.EnumDescriptor(
  name='TodoStatus',
  full_name='rst.calendar.Todo.TodoStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEEDS_ACTION', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_PROCESS', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=329,
  serialized_end=404,
)


_TODO = _descriptor.Descriptor(
  name='Todo',
  full_name='rst.calendar.Todo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='rst.calendar.Todo.entry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed_utc', full_name='rst.calendar.Todo.completed_utc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='percent', full_name='rst.calendar.Todo.percent', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='todo_status', full_name='rst.calendar.Todo.todo_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='due', full_name='rst.calendar.Todo.due', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='duration', full_name='rst.calendar.Todo.duration', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TODO_TODOSTATUS,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=97,
  serialized_end=404,
)

_TODO.fields_by_name['entry'].message_type = rst.calendar.Entry_pb2._ENTRY
_TODO.fields_by_name['completed_utc'].message_type = rst.calendar.DateTime_pb2._DATETIME
_TODO.fields_by_name['todo_status'].enum_type = _TODO_TODOSTATUS
_TODO.fields_by_name['due'].message_type = rst.calendar.DateTime_pb2._DATETIME
_TODO_TODOSTATUS.containing_type = _TODO;
DESCRIPTOR.message_types_by_name['Todo'] = _TODO

class Todo(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TODO

  # @@protoc_insertion_point(class_scope:rst.calendar.Todo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010TodoType')
# @@protoc_insertion_point(module_scope)
