# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/Path.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Pose_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/Path.proto',
  package='rst.navigation',
  serialized_pb='\n\x19rst/navigation/Path.proto\x12\x0erst.navigation\x1a\x17rst/geometry/Pose.proto\")\n\x04Path\x12!\n\x05poses\x18\x01 \x03(\x0b\x32\x12.rst.geometry.PoseB\nB\x08PathType')




_PATH = _descriptor.Descriptor(
  name='Path',
  full_name='rst.navigation.Path',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='poses', full_name='rst.navigation.Path.poses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=70,
  serialized_end=111,
)

_PATH.fields_by_name['poses'].message_type = rst.geometry.Pose_pb2._POSE
DESCRIPTOR.message_types_by_name['Path'] = _PATH

class Path(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PATH

  # @@protoc_insertion_point(class_scope:rst.navigation.Path)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010PathType')
# @@protoc_insertion_point(module_scope)
