# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/OccupancyGrid2DIntCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.navigation.OccupancyGrid2DInt_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/OccupancyGrid2DIntCollection.proto',
  package='rst.navigation',
  serialized_pb='\n1rst/navigation/OccupancyGrid2DIntCollection.proto\x12\x0erst.navigation\x1a\'rst/navigation/OccupancyGrid2DInt.proto\"S\n\x1cOccupancyGrid2DIntCollection\x12\x33\n\x07\x65lement\x18\x01 \x03(\x0b\x32\".rst.navigation.OccupancyGrid2DIntB\"B OccupancyGrid2DIntCollectionType')




_OCCUPANCYGRID2DINTCOLLECTION = _descriptor.Descriptor(
  name='OccupancyGrid2DIntCollection',
  full_name='rst.navigation.OccupancyGrid2DIntCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.navigation.OccupancyGrid2DIntCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=110,
  serialized_end=193,
)

_OCCUPANCYGRID2DINTCOLLECTION.fields_by_name['element'].message_type = rst.navigation.OccupancyGrid2DInt_pb2._OCCUPANCYGRID2DINT
DESCRIPTOR.message_types_by_name['OccupancyGrid2DIntCollection'] = _OCCUPANCYGRID2DINTCOLLECTION

class OccupancyGrid2DIntCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _OCCUPANCYGRID2DINTCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.navigation.OccupancyGrid2DIntCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B OccupancyGrid2DIntCollectionType')
# @@protoc_insertion_point(module_scope)
