# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/navigation/PlatformCapabilities.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/navigation/PlatformCapabilities.proto',
  package='rst.navigation',
  serialized_pb='\n)rst/navigation/PlatformCapabilities.proto\x12\x0erst.navigation\"e\n\x14PlatformCapabilities\x12\x14\n\x0cmax_velocity\x18\x01 \x01(\x02\x12\x18\n\x10max_acceleration\x18\x02 \x01(\x02\x12\x1d\n\x15has_fine_localization\x18\x03 \x01(\x08\x42\x1a\x42\x18PlatformCapabilitiesType')




_PLATFORMCAPABILITIES = _descriptor.Descriptor(
  name='PlatformCapabilities',
  full_name='rst.navigation.PlatformCapabilities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='rst.navigation.PlatformCapabilities.max_velocity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_acceleration', full_name='rst.navigation.PlatformCapabilities.max_acceleration', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_fine_localization', full_name='rst.navigation.PlatformCapabilities.has_fine_localization', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=61,
  serialized_end=162,
)

DESCRIPTOR.message_types_by_name['PlatformCapabilities'] = _PLATFORMCAPABILITIES

class PlatformCapabilities(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PLATFORMCAPABILITIES

  # @@protoc_insertion_point(class_scope:rst.navigation.PlatformCapabilities)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\030PlatformCapabilitiesType')
# @@protoc_insertion_point(module_scope)
