# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassifiedRegion3D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.BoundingBox3DFloat_pb2
import rst.classification.ClassificationResult_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassifiedRegion3D.proto',
  package='rst.classification',
  serialized_pb='\n+rst/classification/ClassifiedRegion3D.proto\x12\x12rst.classification\x1a%rst/geometry/BoundingBox3DFloat.proto\x1a-rst/classification/ClassificationResult.proto\"\x80\x01\n\x12\x43lassifiedRegion3D\x12\x30\n\x06region\x18\x01 \x01(\x0b\x32 .rst.geometry.BoundingBox3DFloat\x12\x38\n\x06result\x18\x02 \x01(\x0b\x32(.rst.classification.ClassificationResultB\x18\x42\x16\x43lassifiedRegion3DType')




_CLASSIFIEDREGION3D = _descriptor.Descriptor(
  name='ClassifiedRegion3D',
  full_name='rst.classification.ClassifiedRegion3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.classification.ClassifiedRegion3D.region', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='rst.classification.ClassifiedRegion3D.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=154,
  serialized_end=282,
)

_CLASSIFIEDREGION3D.fields_by_name['region'].message_type = rst.geometry.BoundingBox3DFloat_pb2._BOUNDINGBOX3DFLOAT
_CLASSIFIEDREGION3D.fields_by_name['result'].message_type = rst.classification.ClassificationResult_pb2._CLASSIFICATIONRESULT
DESCRIPTOR.message_types_by_name['ClassifiedRegion3D'] = _CLASSIFIEDREGION3D

class ClassifiedRegion3D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CLASSIFIEDREGION3D

  # @@protoc_insertion_point(class_scope:rst.classification.ClassifiedRegion3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\026ClassifiedRegion3DType')
# @@protoc_insertion_point(module_scope)
