# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Pose.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Translation_pb2
import rst.geometry.Rotation_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Pose.proto',
  package='rst.geometry',
  serialized_pb='\n\x17rst/geometry/Pose.proto\x12\x0crst.geometry\x1a\x1erst/geometry/Translation.proto\x1a\x1brst/geometry/Rotation.proto\"`\n\x04Pose\x12.\n\x0btranslation\x18\x01 \x02(\x0b\x32\x19.rst.geometry.Translation\x12(\n\x08rotation\x18\x02 \x02(\x0b\x32\x16.rst.geometry.RotationB\nB\x08PoseType')




_POSE = _descriptor.Descriptor(
  name='Pose',
  full_name='rst.geometry.Pose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='translation', full_name='rst.geometry.Pose.translation', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='rst.geometry.Pose.rotation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=102,
  serialized_end=198,
)

_POSE.fields_by_name['translation'].message_type = rst.geometry.Translation_pb2._TRANSLATION
_POSE.fields_by_name['rotation'].message_type = rst.geometry.Rotation_pb2._ROTATION
DESCRIPTOR.message_types_by_name['Pose'] = _POSE

class Pose(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POSE

  # @@protoc_insertion_point(class_scope:rst.geometry.Pose)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010PoseType')
# @@protoc_insertion_point(module_scope)
