# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/SpatialAccelerations.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.LinearAccelerations_pb2
import rst.kinematics.AngularAccelerations_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/SpatialAccelerations.proto',
  package='rst.kinematics',
  serialized_pb='\n)rst/kinematics/SpatialAccelerations.proto\x12\x0erst.kinematics\x1a(rst/kinematics/LinearAccelerations.proto\x1a)rst/kinematics/AngularAccelerations.proto\"\x82\x01\n\x14SpatialAccelerations\x12\x33\n\x06linear\x18\x01 \x02(\x0b\x32#.rst.kinematics.LinearAccelerations\x12\x35\n\x07\x61ngular\x18\x02 \x02(\x0b\x32$.rst.kinematics.AngularAccelerationsB\x1a\x42\x18SpatialAccelerationsType')




_SPATIALACCELERATIONS = _descriptor.Descriptor(
  name='SpatialAccelerations',
  full_name='rst.kinematics.SpatialAccelerations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear', full_name='rst.kinematics.SpatialAccelerations.linear', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angular', full_name='rst.kinematics.SpatialAccelerations.angular', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=147,
  serialized_end=277,
)

_SPATIALACCELERATIONS.fields_by_name['linear'].message_type = rst.kinematics.LinearAccelerations_pb2._LINEARACCELERATIONS
_SPATIALACCELERATIONS.fields_by_name['angular'].message_type = rst.kinematics.AngularAccelerations_pb2._ANGULARACCELERATIONS
DESCRIPTOR.message_types_by_name['SpatialAccelerations'] = _SPATIALACCELERATIONS

class SpatialAccelerations(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SPATIALACCELERATIONS

  # @@protoc_insertion_point(class_scope:rst.kinematics.SpatialAccelerations)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\030SpatialAccelerationsType')
# @@protoc_insertion_point(module_scope)
