# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/PointPairCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.PointPair_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/PointPairCollection.proto',
  package='rst.geometry',
  serialized_pb='\n&rst/geometry/PointPairCollection.proto\x12\x0crst.geometry\x1a\x1crst/geometry/PointPair.proto\"?\n\x13PointPairCollection\x12(\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x17.rst.geometry.PointPairB\x19\x42\x17PointPairCollectionType')




_POINTPAIRCOLLECTION = _descriptor.Descriptor(
  name='PointPairCollection',
  full_name='rst.geometry.PointPairCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.geometry.PointPairCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=86,
  serialized_end=149,
)

_POINTPAIRCOLLECTION.fields_by_name['element'].message_type = rst.geometry.PointPair_pb2._POINTPAIR
DESCRIPTOR.message_types_by_name['PointPairCollection'] = _POINTPAIRCOLLECTION

class PointPairCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POINTPAIRCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.geometry.PointPairCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027PointPairCollectionType')
# @@protoc_insertion_point(module_scope)
