# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Shape3DFloat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.BoundingBox3DFloat_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Shape3DFloat.proto',
  package='rst.geometry',
  serialized_pb='\n\x1frst/geometry/Shape3DFloat.proto\x12\x0crst.geometry\x1a%rst/geometry/BoundingBox3DFloat.proto\"=\n\x0cShape3DFloat\x12-\n\x03\x62ox\x18\x01 \x03(\x0b\x32 .rst.geometry.BoundingBox3DFloatB\x12\x42\x10Shape3DFloatType')




_SHAPE3DFLOAT = _descriptor.Descriptor(
  name='Shape3DFloat',
  full_name='rst.geometry.Shape3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='box', full_name='rst.geometry.Shape3DFloat.box', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=88,
  serialized_end=149,
)

_SHAPE3DFLOAT.fields_by_name['box'].message_type = rst.geometry.BoundingBox3DFloat_pb2._BOUNDINGBOX3DFLOAT
DESCRIPTOR.message_types_by_name['Shape3DFloat'] = _SHAPE3DFLOAT

class Shape3DFloat(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SHAPE3DFLOAT

  # @@protoc_insertion_point(class_scope:rst.geometry.Shape3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\020Shape3DFloatType')
# @@protoc_insertion_point(module_scope)
