# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/UserState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/UserState.proto',
  package='rst.devices.generic',
  serialized_pb='\n#rst/devices/generic/UserState.proto\x12\x13rst.devices.generic\"Q\n\tUserState\x12\x17\n\x0flogged_in_users\x18\x01 \x01(\r\x12\x16\n\x0elogin_sessions\x18\x02 \x01(\r\x12\x13\n\x0blogin_hosts\x18\x03 \x01(\rB\x0f\x42\rUserStateType')




_USERSTATE = _descriptor.Descriptor(
  name='UserState',
  full_name='rst.devices.generic.UserState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logged_in_users', full_name='rst.devices.generic.UserState.logged_in_users', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='login_sessions', full_name='rst.devices.generic.UserState.login_sessions', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='login_hosts', full_name='rst.devices.generic.UserState.login_hosts', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=60,
  serialized_end=141,
)

DESCRIPTOR.message_types_by_name['UserState'] = _USERSTATE

class UserState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _USERSTATE

  # @@protoc_insertion_point(class_scope:rst.devices.generic.UserState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\rUserStateType')
# @@protoc_insertion_point(module_scope)
