# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/generic/Dictionary.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.generic.KeyValuePair_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/generic/Dictionary.proto',
  package='rst.generic',
  serialized_pb='\n\x1crst/generic/Dictionary.proto\x12\x0brst.generic\x1a\x1erst/generic/KeyValuePair.proto\"8\n\nDictionary\x12*\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x19.rst.generic.KeyValuePairB\x10\x42\x0e\x44ictionaryType')




_DICTIONARY = _descriptor.Descriptor(
  name='Dictionary',
  full_name='rst.generic.Dictionary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='rst.generic.Dictionary.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=77,
  serialized_end=133,
)

_DICTIONARY.fields_by_name['entries'].message_type = rst.generic.KeyValuePair_pb2._KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['Dictionary'] = _DICTIONARY

class Dictionary(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _DICTIONARY

  # @@protoc_insertion_point(class_scope:rst.generic.Dictionary)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016DictionaryType')
# @@protoc_insertion_point(module_scope)
