# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/Posture3DFloat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Rotation_pb2
import rst.geometry.Translation_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/Posture3DFloat.proto',
  package='rst.kinematics',
  serialized_pb='\n#rst/kinematics/Posture3DFloat.proto\x12\x0erst.kinematics\x1a\x1brst/geometry/Rotation.proto\x1a\x1erst/geometry/Translation.proto\"u\n\x0ePosture3DFloat\x12+\n\x08position\x18\x02 \x03(\x0b\x32\x19.rst.geometry.Translation\x12(\n\x08rotation\x18\x03 \x03(\x0b\x32\x16.rst.geometry.Rotation\x12\x0c\n\x04name\x18\x04 \x03(\x0c\x42\x14\x42\x12Posture3DFloatType')




_POSTURE3DFLOAT = _descriptor.Descriptor(
  name='Posture3DFloat',
  full_name='rst.kinematics.Posture3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='rst.kinematics.Posture3DFloat.position', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='rst.kinematics.Posture3DFloat.rotation', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.kinematics.Posture3DFloat.name', index=2,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=116,
  serialized_end=233,
)

_POSTURE3DFLOAT.fields_by_name['position'].message_type = rst.geometry.Translation_pb2._TRANSLATION
_POSTURE3DFLOAT.fields_by_name['rotation'].message_type = rst.geometry.Rotation_pb2._ROTATION
DESCRIPTOR.message_types_by_name['Posture3DFloat'] = _POSTURE3DFLOAT

class Posture3DFloat(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POSTURE3DFLOAT

  # @@protoc_insertion_point(class_scope:rst.kinematics.Posture3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\022Posture3DFloatType')
# @@protoc_insertion_point(module_scope)
