# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/timing/Point2DTimestampPair.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.timing.Timestamp_pb2
import rst.math.Vec2DFloat_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/timing/Point2DTimestampPair.proto',
  package='rst.timing',
  serialized_pb='\n%rst/timing/Point2DTimestampPair.proto\x12\nrst.timing\x1a\x1arst/timing/Timestamp.proto\x1a\x19rst/math/Vec2DFloat.proto\"e\n\x14Point2DTimestampPair\x12#\n\x05point\x18\x01 \x02(\x0b\x32\x14.rst.math.Vec2DFloat\x12(\n\ttimestamp\x18\x02 \x02(\x0b\x32\x15.rst.timing.TimestampB\x1a\x42\x18Point2DTimestampPairType')




_POINT2DTIMESTAMPPAIR = _descriptor.Descriptor(
  name='Point2DTimestampPair',
  full_name='rst.timing.Point2DTimestampPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='rst.timing.Point2DTimestampPair.point', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='rst.timing.Point2DTimestampPair.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=108,
  serialized_end=209,
)

_POINT2DTIMESTAMPPAIR.fields_by_name['point'].message_type = rst.math.Vec2DFloat_pb2._VEC2DFLOAT
_POINT2DTIMESTAMPPAIR.fields_by_name['timestamp'].message_type = rst.timing.Timestamp_pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Point2DTimestampPair'] = _POINT2DTIMESTAMPPAIR

class Point2DTimestampPair(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _POINT2DTIMESTAMPPAIR

  # @@protoc_insertion_point(class_scope:rst.timing.Point2DTimestampPair)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\030Point2DTimestampPairType')
# @@protoc_insertion_point(module_scope)
