# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/LinearVelocities.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/LinearVelocities.proto',
  package='rst.kinematics',
  serialized_pb='\n%rst/kinematics/LinearVelocities.proto\x12\x0erst.kinematics\"3\n\x10LinearVelocities\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x42\x16\x42\x14LinearVelocitiesType')




_LINEARVELOCITIES = _descriptor.Descriptor(
  name='LinearVelocities',
  full_name='rst.kinematics.LinearVelocities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.kinematics.LinearVelocities.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.kinematics.LinearVelocities.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='rst.kinematics.LinearVelocities.z', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=57,
  serialized_end=108,
)

DESCRIPTOR.message_types_by_name['LinearVelocities'] = _LINEARVELOCITIES

class LinearVelocities(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _LINEARVELOCITIES

  # @@protoc_insertion_point(class_scope:rst.kinematics.LinearVelocities)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\024LinearVelocitiesType')
# @@protoc_insertion_point(module_scope)
