# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/calendar/RequestStatus.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/calendar/RequestStatus.proto',
  package='rst.calendar',
  serialized_pb='\n rst/calendar/RequestStatus.proto\x12\x0crst.calendar\"o\n\rRequestStatus\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x13\n\x0bstatus_code\x18\x02 \x02(\t\x12\x1a\n\x12status_description\x18\x03 \x02(\t\x12\x1b\n\x13\x65xception_text_data\x18\x04 \x02(\tB\x13\x42\x11RequestStatusType')




_REQUESTSTATUS = _descriptor.Descriptor(
  name='RequestStatus',
  full_name='rst.calendar.RequestStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='rst.calendar.RequestStatus.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='rst.calendar.RequestStatus.status_code', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_description', full_name='rst.calendar.RequestStatus.status_description', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exception_text_data', full_name='rst.calendar.RequestStatus.exception_text_data', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=50,
  serialized_end=161,
)

DESCRIPTOR.message_types_by_name['RequestStatus'] = _REQUESTSTATUS

class RequestStatus(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _REQUESTSTATUS

  # @@protoc_insertion_point(class_scope:rst.calendar.RequestStatus)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\021RequestStatusType')
# @@protoc_insertion_point(module_scope)
