# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/FieldOfView.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/FieldOfView.proto',
  package='rst.geometry',
  serialized_pb='\n\x1erst/geometry/FieldOfView.proto\x12\x0crst.geometry\";\n\x0b\x46ieldOfView\x12\x16\n\x0ehorizontal_aov\x18\x01 \x02(\x02\x12\x14\n\x0cvertical_aov\x18\x02 \x02(\x02\x42\x11\x42\x0f\x46ieldOfViewType')




_FIELDOFVIEW = _descriptor.Descriptor(
  name='FieldOfView',
  full_name='rst.geometry.FieldOfView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='horizontal_aov', full_name='rst.geometry.FieldOfView.horizontal_aov', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vertical_aov', full_name='rst.geometry.FieldOfView.vertical_aov', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=48,
  serialized_end=107,
)

DESCRIPTOR.message_types_by_name['FieldOfView'] = _FIELDOFVIEW

class FieldOfView(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FIELDOFVIEW

  # @@protoc_insertion_point(class_scope:rst.geometry.FieldOfView)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\017FieldOfViewType')
# @@protoc_insertion_point(module_scope)
