# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/motioncontrol/MotionStatus.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/motioncontrol/MotionStatus.proto',
  package='rst.motioncontrol',
  serialized_pb='\n$rst/motioncontrol/MotionStatus.proto\x12\x11rst.motioncontrol\"!\n\x0cMotionStatus\x12\x11\n\tconverged\x18\x01 \x02(\x08\x42\x12\x42\x10MotionStatusType')




_MOTIONSTATUS = _descriptor.Descriptor(
  name='MotionStatus',
  full_name='rst.motioncontrol.MotionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='converged', full_name='rst.motioncontrol.MotionStatus.converged', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=59,
  serialized_end=92,
)

DESCRIPTOR.message_types_by_name['MotionStatus'] = _MOTIONSTATUS

class MotionStatus(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MOTIONSTATUS

  # @@protoc_insertion_point(class_scope:rst.motioncontrol.MotionStatus)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\020MotionStatusType')
# @@protoc_insertion_point(module_scope)
