# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Face.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.BoundingBox_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Face.proto',
  package='rst.vision',
  serialized_pb='\n\x15rst/vision/Face.proto\x12\nrst.vision\x1a\x1erst/geometry/BoundingBox.proto\"E\n\x04\x46\x61\x63\x65\x12)\n\x06region\x18\x01 \x02(\x0b\x32\x19.rst.geometry.BoundingBox\x12\x12\n\nconfidence\x18\x02 \x01(\x01\x42\nB\x08\x46\x61\x63\x65Type')




_FACE = _descriptor.Descriptor(
  name='Face',
  full_name='rst.vision.Face',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.vision.Face.region', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='rst.vision.Face.confidence', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=69,
  serialized_end=138,
)

_FACE.fields_by_name['region'].message_type = rst.geometry.BoundingBox_pb2._BOUNDINGBOX
DESCRIPTOR.message_types_by_name['Face'] = _FACE

class Face(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FACE

  # @@protoc_insertion_point(class_scope:rst.vision.Face)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010FaceType')
# @@protoc_insertion_point(module_scope)
