# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/Twist.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.LinearVelocities_pb2
import rst.kinematics.AngularVelocities_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/Twist.proto',
  package='rst.kinematics',
  serialized_pb='\n\x1arst/kinematics/Twist.proto\x12\x0erst.kinematics\x1a%rst/kinematics/LinearVelocities.proto\x1a&rst/kinematics/AngularVelocities.proto\"m\n\x05Twist\x12\x30\n\x06linear\x18\x01 \x02(\x0b\x32 .rst.kinematics.LinearVelocities\x12\x32\n\x07\x61ngular\x18\x02 \x02(\x0b\x32!.rst.kinematics.AngularVelocitiesB\x0b\x42\tTwistType')




_TWIST = _descriptor.Descriptor(
  name='Twist',
  full_name='rst.kinematics.Twist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='linear', full_name='rst.kinematics.Twist.linear', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angular', full_name='rst.kinematics.Twist.angular', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=125,
  serialized_end=234,
)

_TWIST.fields_by_name['linear'].message_type = rst.kinematics.LinearVelocities_pb2._LINEARVELOCITIES
_TWIST.fields_by_name['angular'].message_type = rst.kinematics.AngularVelocities_pb2._ANGULARVELOCITIES
DESCRIPTOR.message_types_by_name['Twist'] = _TWIST

class Twist(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TWIST

  # @@protoc_insertion_point(class_scope:rst.kinematics.Twist)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\tTwistType')
# @@protoc_insertion_point(module_scope)
