# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassifiedRegions2D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.classification.ClassifiedRegion2D_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassifiedRegions2D.proto',
  package='rst.classification',
  serialized_pb='\n,rst/classification/ClassifiedRegions2D.proto\x12\x12rst.classification\x1a+rst/classification/ClassifiedRegion2D.proto\"N\n\x13\x43lassifiedRegions2D\x12\x37\n\x07regions\x18\x01 \x03(\x0b\x32&.rst.classification.ClassifiedRegion2DB\x19\x42\x17\x43lassifiedRegions2DType')




_CLASSIFIEDREGIONS2D = _descriptor.Descriptor(
  name='ClassifiedRegions2D',
  full_name='rst.classification.ClassifiedRegions2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='regions', full_name='rst.classification.ClassifiedRegions2D.regions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=113,
  serialized_end=191,
)

_CLASSIFIEDREGIONS2D.fields_by_name['regions'].message_type = rst.classification.ClassifiedRegion2D_pb2._CLASSIFIEDREGION2D
DESCRIPTOR.message_types_by_name['ClassifiedRegions2D'] = _CLASSIFIEDREGIONS2D

class ClassifiedRegions2D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CLASSIFIEDREGIONS2D

  # @@protoc_insertion_point(class_scope:rst.classification.ClassifiedRegions2D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027ClassifiedRegions2DType')
# @@protoc_insertion_point(module_scope)
