# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/States.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.tracking.State_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/States.proto',
  package='rst.tracking',
  serialized_pb='\n\x19rst/tracking/States.proto\x12\x0crst.tracking\x1a\x18rst/tracking/State.proto\",\n\x06States\x12\"\n\x05state\x18\x01 \x03(\x0b\x32\x13.rst.tracking.StateB\x0c\x42\nStatesType')




_STATES = _descriptor.Descriptor(
  name='States',
  full_name='rst.tracking.States',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='rst.tracking.States.state', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=69,
  serialized_end=113,
)

_STATES.fields_by_name['state'].message_type = rst.tracking.State_pb2._STATE
DESCRIPTOR.message_types_by_name['States'] = _STATES

class States(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _STATES

  # @@protoc_insertion_point(class_scope:rst.tracking.States)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\nStatesType')
# @@protoc_insertion_point(module_scope)
