# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/Images.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.vision.Image_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/Images.proto',
  package='rst.vision',
  serialized_pb='\n\x17rst/vision/Images.proto\x12\nrst.vision\x1a\x16rst/vision/Image.proto\"+\n\x06Images\x12!\n\x06images\x18\x01 \x03(\x0b\x32\x11.rst.vision.ImageB\x0c\x42\nImagesType')




_IMAGES = _descriptor.Descriptor(
  name='Images',
  full_name='rst.vision.Images',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='images', full_name='rst.vision.Images.images', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=63,
  serialized_end=106,
)

_IMAGES.fields_by_name['images'].message_type = rst.vision.Image_pb2._IMAGE
DESCRIPTOR.message_types_by_name['Images'] = _IMAGES

class Images(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _IMAGES

  # @@protoc_insertion_point(class_scope:rst.vision.Images)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\nImagesType')
# @@protoc_insertion_point(module_scope)
