# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/graph/Edge.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.generic.Value_pb2
import rst.generic.Dictionary_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/graph/Edge.proto',
  package='rst.graph',
  serialized_pb='\n\x14rst/graph/Edge.proto\x12\trst.graph\x1a\x17rst/generic/Value.proto\x1a\x1crst/generic/Dictionary.proto\"q\n\x04\x45\x64ge\x12\x0c\n\x04head\x18\x01 \x02(\r\x12\x0c\n\x04tail\x18\x02 \x02(\r\x12 \n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x12.rst.generic.Value\x12+\n\nproperties\x18\x04 \x01(\x0b\x32\x17.rst.generic.DictionaryB\nB\x08\x45\x64geType')




_EDGE = _descriptor.Descriptor(
  name='Edge',
  full_name='rst.graph.Edge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='head', full_name='rst.graph.Edge.head', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tail', full_name='rst.graph.Edge.tail', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='rst.graph.Edge.data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='rst.graph.Edge.properties', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=90,
  serialized_end=203,
)

_EDGE.fields_by_name['data'].message_type = rst.generic.Value_pb2._VALUE
_EDGE.fields_by_name['properties'].message_type = rst.generic.Dictionary_pb2._DICTIONARY
DESCRIPTOR.message_types_by_name['Edge'] = _EDGE

class Edge(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _EDGE

  # @@protoc_insertion_point(class_scope:rst.graph.Edge)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010EdgeType')
# @@protoc_insertion_point(module_scope)
