# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/math/Vec2DInt.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/math/Vec2DInt.proto',
  package='rst.math',
  serialized_pb='\n\x17rst/math/Vec2DInt.proto\x12\x08rst.math\"&\n\x08Vec2DInt\x12\x0c\n\x01x\x18\x01 \x02(\x05:\x01\x30\x12\x0c\n\x01y\x18\x02 \x02(\x05:\x01\x30\x42\x0e\x42\x0cVec2DIntType')




_VEC2DINT = _descriptor.Descriptor(
  name='Vec2DInt',
  full_name='rst.math.Vec2DInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='rst.math.Vec2DInt.x', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='rst.math.Vec2DInt.y', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=37,
  serialized_end=75,
)

DESCRIPTOR.message_types_by_name['Vec2DInt'] = _VEC2DINT

class Vec2DInt(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _VEC2DINT

  # @@protoc_insertion_point(class_scope:rst.math.Vec2DInt)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\014Vec2DIntType')
# @@protoc_insertion_point(module_scope)
