# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/ViewFrustumCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.ViewFrustum_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/ViewFrustumCollection.proto',
  package='rst.geometry',
  serialized_pb='\n(rst/geometry/ViewFrustumCollection.proto\x12\x0crst.geometry\x1a\x1erst/geometry/ViewFrustum.proto\"C\n\x15ViewFrustumCollection\x12*\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x19.rst.geometry.ViewFrustumB\x1b\x42\x19ViewFrustumCollectionType')




_VIEWFRUSTUMCOLLECTION = _descriptor.Descriptor(
  name='ViewFrustumCollection',
  full_name='rst.geometry.ViewFrustumCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.geometry.ViewFrustumCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=90,
  serialized_end=157,
)

_VIEWFRUSTUMCOLLECTION.fields_by_name['element'].message_type = rst.geometry.ViewFrustum_pb2._VIEWFRUSTUM
DESCRIPTOR.message_types_by_name['ViewFrustumCollection'] = _VIEWFRUSTUMCOLLECTION

class ViewFrustumCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _VIEWFRUSTUMCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.geometry.ViewFrustumCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\031ViewFrustumCollectionType')
# @@protoc_insertion_point(module_scope)
