# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/stochastics/Gaussian1D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/stochastics/Gaussian1D.proto',
  package='rst.stochastics',
  serialized_pb='\n rst/stochastics/Gaussian1D.proto\x12\x0frst.stochastics\",\n\nGaussian1D\x12\x0c\n\x04mean\x18\x01 \x02(\x02\x12\x10\n\x08variance\x18\x02 \x02(\x02\x42\x10\x42\x0eGaussian1DType')




_GAUSSIAN1D = _descriptor.Descriptor(
  name='Gaussian1D',
  full_name='rst.stochastics.Gaussian1D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mean', full_name='rst.stochastics.Gaussian1D.mean', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='variance', full_name='rst.stochastics.Gaussian1D.variance', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=53,
  serialized_end=97,
)

DESCRIPTOR.message_types_by_name['Gaussian1D'] = _GAUSSIAN1D

class Gaussian1D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _GAUSSIAN1D

  # @@protoc_insertion_point(class_scope:rst.stochastics.Gaussian1D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016Gaussian1DType')
# @@protoc_insertion_point(module_scope)
