# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/Body.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Translation_pb2
import rst.geometry.Rotation_pb2
import rst.geometry.BoundingBox3DFloat_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/Body.proto',
  package='rst.hri',
  serialized_pb='\n\x12rst/hri/Body.proto\x12\x07rst.hri\x1a\x1erst/geometry/Translation.proto\x1a\x1brst/geometry/Rotation.proto\x1a%rst/geometry/BoundingBox3DFloat.proto\"\x91\x01\n\x04\x42ody\x12+\n\x08location\x18\n \x01(\x0b\x32\x19.rst.geometry.Translation\x12+\n\x0borientation\x18\x14 \x01(\x0b\x32\x16.rst.geometry.Rotation\x12/\n\x05shape\x18\x1e \x01(\x0b\x32 .rst.geometry.BoundingBox3DFloatB\nB\x08\x42odyType')




_BODY = _descriptor.Descriptor(
  name='Body',
  full_name='rst.hri.Body',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='rst.hri.Body.location', index=0,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='rst.hri.Body.orientation', index=1,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='shape', full_name='rst.hri.Body.shape', index=2,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=132,
  serialized_end=277,
)

_BODY.fields_by_name['location'].message_type = rst.geometry.Translation_pb2._TRANSLATION
_BODY.fields_by_name['orientation'].message_type = rst.geometry.Rotation_pb2._ROTATION
_BODY.fields_by_name['shape'].message_type = rst.geometry.BoundingBox3DFloat_pb2._BOUNDINGBOX3DFLOAT
DESCRIPTOR.message_types_by_name['Body'] = _BODY

class Body(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _BODY

  # @@protoc_insertion_point(class_scope:rst.hri.Body)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\010BodyType')
# @@protoc_insertion_point(module_scope)
