# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/generic/KeyValuePair.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.generic.Value_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/generic/KeyValuePair.proto',
  package='rst.generic',
  serialized_pb='\n\x1erst/generic/KeyValuePair.proto\x12\x0brst.generic\x1a\x17rst/generic/Value.proto\">\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x02(\t\x12!\n\x05value\x18\x02 \x02(\x0b\x32\x12.rst.generic.ValueB\x12\x42\x10KeyValuePairType')




_KEYVALUEPAIR = _descriptor.Descriptor(
  name='KeyValuePair',
  full_name='rst.generic.KeyValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='rst.generic.KeyValuePair.key', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='rst.generic.KeyValuePair.value', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=72,
  serialized_end=134,
)

_KEYVALUEPAIR.fields_by_name['value'].message_type = rst.generic.Value_pb2._VALUE
DESCRIPTOR.message_types_by_name['KeyValuePair'] = _KEYVALUEPAIR

class KeyValuePair(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _KEYVALUEPAIR

  # @@protoc_insertion_point(class_scope:rst.generic.KeyValuePair)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\020KeyValuePairType')
# @@protoc_insertion_point(module_scope)
