# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/robot/PickAndPlaceAction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Pose_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/robot/PickAndPlaceAction.proto',
  package='rst.robot',
  serialized_pb='\n\"rst/robot/PickAndPlaceAction.proto\x12\trst.robot\x1a\x17rst/geometry/Pose.proto\"a\n\x12PickAndPlaceAction\x12$\n\x08pickPose\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12%\n\tplacePose\x18\x02 \x02(\x0b\x32\x12.rst.geometry.PoseB\x18\x42\x16PickAndPlaceActionType')




_PICKANDPLACEACTION = _descriptor.Descriptor(
  name='PickAndPlaceAction',
  full_name='rst.robot.PickAndPlaceAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pickPose', full_name='rst.robot.PickAndPlaceAction.pickPose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='placePose', full_name='rst.robot.PickAndPlaceAction.placePose', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=74,
  serialized_end=171,
)

_PICKANDPLACEACTION.fields_by_name['pickPose'].message_type = rst.geometry.Pose_pb2._POSE
_PICKANDPLACEACTION.fields_by_name['placePose'].message_type = rst.geometry.Pose_pb2._POSE
DESCRIPTOR.message_types_by_name['PickAndPlaceAction'] = _PICKANDPLACEACTION

class PickAndPlaceAction(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PICKANDPLACEACTION

  # @@protoc_insertion_point(class_scope:rst.robot.PickAndPlaceAction)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\026PickAndPlaceActionType')
# @@protoc_insertion_point(module_scope)
