# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dialog/DialogActCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.dialog.DialogAct_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dialog/DialogActCollection.proto',
  package='rst.dialog',
  serialized_pb='\n$rst/dialog/DialogActCollection.proto\x12\nrst.dialog\x1a\x1arst/dialog/DialogAct.proto\"=\n\x13\x44ialogActCollection\x12&\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x15.rst.dialog.DialogActB\x19\x42\x17\x44ialogActCollectionType')




_DIALOGACTCOLLECTION = _descriptor.Descriptor(
  name='DialogActCollection',
  full_name='rst.dialog.DialogActCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.dialog.DialogActCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=80,
  serialized_end=141,
)

_DIALOGACTCOLLECTION.fields_by_name['element'].message_type = rst.dialog.DialogAct_pb2._DIALOGACT
DESCRIPTOR.message_types_by_name['DialogActCollection'] = _DIALOGACTCOLLECTION

class DialogActCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _DIALOGACTCOLLECTION

  # @@protoc_insertion_point(class_scope:rst.dialog.DialogActCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027DialogActCollectionType')
# @@protoc_insertion_point(module_scope)
