# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/dynamics/Wrench.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.dynamics.Forces_pb2
import rst.dynamics.Torques_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/dynamics/Wrench.proto',
  package='rst.dynamics',
  serialized_pb='\n\x19rst/dynamics/Wrench.proto\x12\x0crst.dynamics\x1a\x19rst/dynamics/Forces.proto\x1a\x1arst/dynamics/Torques.proto\"V\n\x06Wrench\x12$\n\x06\x66orces\x18\x01 \x02(\x0b\x32\x14.rst.dynamics.Forces\x12&\n\x07torques\x18\x02 \x02(\x0b\x32\x15.rst.dynamics.TorquesB\x0c\x42\nWrenchType')




_WRENCH = _descriptor.Descriptor(
  name='Wrench',
  full_name='rst.dynamics.Wrench',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='forces', full_name='rst.dynamics.Wrench.forces', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='torques', full_name='rst.dynamics.Wrench.torques', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=98,
  serialized_end=184,
)

_WRENCH.fields_by_name['forces'].message_type = rst.dynamics.Forces_pb2._FORCES
_WRENCH.fields_by_name['torques'].message_type = rst.dynamics.Torques_pb2._TORQUES
DESCRIPTOR.message_types_by_name['Wrench'] = _WRENCH

class Wrench(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _WRENCH

  # @@protoc_insertion_point(class_scope:rst.dynamics.Wrench)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\nWrenchType')
# @@protoc_insertion_point(module_scope)
