# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/AxisAlignedBoundingBox3DFloat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Translation_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/AxisAlignedBoundingBox3DFloat.proto',
  package='rst.geometry',
  serialized_pb='\n0rst/geometry/AxisAlignedBoundingBox3DFloat.proto\x12\x0crst.geometry\x1a\x1erst/geometry/Translation.proto\"\x83\x01\n\x1d\x41xisAlignedBoundingBox3DFloat\x12\x34\n\x11left_front_bottom\x18\x01 \x02(\x0b\x32\x19.rst.geometry.Translation\x12\r\n\x05width\x18\x02 \x02(\x02\x12\r\n\x05\x64\x65pth\x18\x03 \x02(\x02\x12\x0e\n\x06height\x18\x04 \x02(\x02\x42#B!AxisAlignedBoundingBox3DFloatType')




_AXISALIGNEDBOUNDINGBOX3DFLOAT = _descriptor.Descriptor(
  name='AxisAlignedBoundingBox3DFloat',
  full_name='rst.geometry.AxisAlignedBoundingBox3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='left_front_bottom', full_name='rst.geometry.AxisAlignedBoundingBox3DFloat.left_front_bottom', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='width', full_name='rst.geometry.AxisAlignedBoundingBox3DFloat.width', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='depth', full_name='rst.geometry.AxisAlignedBoundingBox3DFloat.depth', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.geometry.AxisAlignedBoundingBox3DFloat.height', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=99,
  serialized_end=230,
)

_AXISALIGNEDBOUNDINGBOX3DFLOAT.fields_by_name['left_front_bottom'].message_type = rst.geometry.Translation_pb2._TRANSLATION
DESCRIPTOR.message_types_by_name['AxisAlignedBoundingBox3DFloat'] = _AXISALIGNEDBOUNDINGBOX3DFLOAT

class AxisAlignedBoundingBox3DFloat(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AXISALIGNEDBOUNDINGBOX3DFLOAT

  # @@protoc_insertion_point(class_scope:rst.geometry.AxisAlignedBoundingBox3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B!AxisAlignedBoundingBox3DFloatType')
# @@protoc_insertion_point(module_scope)
