# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackingInfo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackingInfo.proto',
  package='rst.tracking',
  serialized_pb='\n\x1frst/tracking/TrackingInfo.proto\x12\x0crst.tracking\"1\n\x0cTrackingInfo\x12\n\n\x02id\x18\x01 \x02(\r\x12\x15\n\rpersistent_id\x18\x02 \x01(\x0c\x42\x12\x42\x10TrackingInfoType')




_TRACKINGINFO = _descriptor.Descriptor(
  name='TrackingInfo',
  full_name='rst.tracking.TrackingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='rst.tracking.TrackingInfo.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='persistent_id', full_name='rst.tracking.TrackingInfo.persistent_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=49,
  serialized_end=98,
)

DESCRIPTOR.message_types_by_name['TrackingInfo'] = _TRACKINGINFO

class TrackingInfo(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRACKINGINFO

  # @@protoc_insertion_point(class_scope:rst.tracking.TrackingInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\020TrackingInfoType')
# @@protoc_insertion_point(module_scope)
